@@ -1,7 +1,5 @@
 package CHI::Driver;
-{
-  $CHI::Driver::VERSION = '0.58';
-}
+$CHI::Driver::VERSION = '0.60';
 use Carp;
 use CHI::CacheObject;
 use CHI::Constants qw(CHI_Max_Time);
@@ -37,104 +35,105 @@ my @common_params;
             is => 'ro',
         },
         compress_threshold => {
-            is => 'ro',
+            is  => 'ro',
             isa => Int,
         },
         constructor_params => {
-            is => 'ro',
+            is       => 'ro',
             init_arg => undef,
         },
         driver_class => {
             is => 'ro',
         },
         expires_at => {
-            is => 'rw',
+            is      => 'rw',
             default => sub { CHI_Max_Time },
         },
-        expires_in => { is => 'rw',
-            isa => Duration,
+        expires_in => {
+            is     => 'rw',
+            isa    => Duration,
             coerce => \&to_Duration,
         },
         expires_on_backend => {
-            is => 'ro',
-            isa => Num,
+            is      => 'ro',
+            isa     => Num,
             default => sub { 0 },
         },
         expires_variance => {
-            is => 'rw',
-            isa => Num,
+            is      => 'rw',
+            isa     => Num,
             default => sub { 0 },
         },
         has_subcaches => {
-            is => 'lazy',
-            isa => Bool,
+            is       => 'lazy',
+            isa      => Bool,
             init_arg => undef,
         },
         is_size_aware => {
-            is => 'ro',
+            is  => 'ro',
             isa => Bool,
         },
         is_subcache => {
-            is => 'ro',
+            is  => 'ro',
             isa => Bool,
         },
         key_digester => {
-            is => 'ro',
-            isa => Digester,
-            coerce => \&to_Digester,
+            is      => 'ro',
+            isa     => Digester,
+            coerce  => \&to_Digester,
             default => sub { $default_key_digester },
         },
         key_serializer => {
-            is => 'ro',
-            isa => Serializer,
-            coerce => \&to_Serializer,
+            is      => 'ro',
+            isa     => Serializer,
+            coerce  => \&to_Serializer,
             default => sub { $default_key_serializer },
         },
         label => {
-            is => 'rw',
-            lazy => 1,
-            builder => 1,
-            clearer => 1,
+            is        => 'rw',
+            lazy      => 1,
+            builder   => 1,
+            clearer   => 1,
             predicate => 1,
         },
         max_build_depth => {
-            is => 'ro',
+            is      => 'ro',
             default => sub { 8 },
         },
         max_key_length => {
-            is => 'ro',
-            isa => Int,
+            is      => 'ro',
+            isa     => Int,
             default => sub { 1 << 31 },
         },
         metacache => {
-            is => 'lazy',
-            clearer => 1,
+            is        => 'lazy',
+            clearer   => 1,
             predicate => 1,
         },
         namespace => {
-            is => 'ro',
-            isa => Str,
+            is      => 'ro',
+            isa     => Str,
             default => sub { 'Default' },
         },
         on_get_error => {
-            is => 'rw',
-            isa => OnError,
+            is      => 'rw',
+            isa     => OnError,
             default => sub { 'log' },
         },
         on_set_error => {
-            is => 'rw',
-            isa => OnError,
+            is      => 'rw',
+            isa     => OnError,
             default => sub { 'log' },
         },
         serializer => {
-            is => 'ro',
-            isa => Serializer,
-            coerce => \&to_Serializer,
+            is      => 'ro',
+            isa     => Serializer,
+            coerce  => \&to_Serializer,
             default => sub { $default_serializer },
         },
         short_driver_name => {
-            is => 'lazy',
-            clearer => 1,
+            is        => 'lazy',
+            clearer   => 1,
             predicate => 1,
         },
         storage => {
@@ -143,7 +142,7 @@ my @common_params;
     );
     push @common_params, keys %attr;
     for my $attr ( keys %attr ) {
-        has $attr => %{$attr{$attr}};
+        has $attr => %{ $attr{$attr} };
     }
 }
 
@@ -158,15 +157,15 @@ foreach my $method (qw(fetch store remove get_keys get_namespaces)) {
 # Given a hash of params, return the subset that are not in CHI's common parameters.
 #
 push @common_params, qw(
-    discard_policy
-    discard_timeout
-    l1_cache
-    max_size
-    max_size_reduction_factor
-    mirror_cache
-    parent_cache
-    subcache_type
-    subcaches
+  discard_policy
+  discard_timeout
+  l1_cache
+  max_size
+  max_size_reduction_factor
+  mirror_cache
+  parent_cache
+  subcache_type
+  subcaches
 );
 my %common_params = map { ( $_, 1 ) } @common_params;
 
@@ -184,7 +183,8 @@ sub declare_unsupported_methods {
 
     foreach my $method (@methods) {
         no strict 'refs';
-        *{"$class\::$method"} = sub { croak "method '$method' not supported by '$class'" };
+        *{"$class\::$method"} =
+          sub { croak "method '$method' not supported by '$class'" };
     }
 }
 
@@ -285,7 +285,8 @@ sub get {
     # Check if expired
     #
     my $is_expired = $obj->is_expired()
-      || ( defined( $params{expire_if} ) && $params{expire_if}->($obj) );
+      || ( defined( $params{expire_if} )
+        && $params{expire_if}->( $obj, $self ) );
     if ($is_expired) {
         $self->_record_get_stats( 'expired_misses', $elapsed_time )
           if defined($ns_stats);
@@ -848,7 +849,7 @@ CHI::Driver - Base class for all CHI drivers
 
 =head1 VERSION
 
-version 0.58
+version 0.60
 
 =head1 DESCRIPTION
 
